@@ -1,14 +1,19 @@
 from setuptools import setup, find_packages
 
+import os
+lib_folder = os.path.dirname(os.path.realpath(__file__))
+requirements_file = os.path.join(lib_folder, 'requirements.txt')
+install_requires = ["requests >= 2.25.1", "setuptools >= 56.0.0"]
+if os.path.exists(requirements_file):
+    with open(requirements_file, 'r') as f:
+        install_requires = f.read().splitlines()
+
 setup(
     name='apiverve_airquality',
-    version='1.1.2',
+    version='1.1.5',
     packages=find_packages(),
     include_package_data=True,
-    install_requires=[
-        'requests',
-        'setuptools'
-    ],
+    install_requires=install_requires,
     description='Air Quality is a simple tool for getting air quality data. It returns the air quality index, o3, pm2, and more.',
     author='APIVerve',
     author_email='hello@apiverve.com',
@@ -18,4 +23,4 @@ setup(
         'Operating System :: OS Independent',
     ],
     python_requires='>=3.6',
-)
+)
\ No newline at end of file
